Change Log
==========

Unreleased Changed
------------------
* add pdf sampler
* namechange ``km3like.pseudo`` -> ``km3like.sample``

0.2.1 - 20/07/2017
----------------
* add BaseLLHNoExog and derive other pointsource classes from it
* add ScrambledBootstrap sampler (bootstrapped events + random azimuth/time)
